@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "3.2.0"
+__version__ = "3.2.2"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -31,7 +31,7 @@ class _EvalEnvironment(dict):
         self.parent = parent
 
     def __getitem__(self, item):
-        if item == '_parent_' + self.parent._parent_field_name \
+        if item == '_parent_' + self.parent._parent_name \
                 and self.parent.parent:
             return _EvalEnvironment(self.parent.parent)
         return self.parent._get_eval()[item]
@@ -278,17 +278,21 @@ class One2ManyValueDescriptor(ValueDescriptor):
     def __get__(self, instance, owner):
         value = []
         value_list = getattr(instance, self.name)
+        parent_name = self.definition.get('relation_field', '')
         to_add = []
         to_create = []
         to_write = []
         for record in value_list:
             if record.id >= 0:
-                if record._changed:
-                    to_write.extend(([record.id],
-                            record._get_values(fields=record._changed)))
+                values = record._get_values(fields=record._changed)
+                values.pop(parent_name, None)
+                if record._changed and values:
+                    to_write.extend(([record.id], values))
                 to_add.append(record.id)
             else:
-                to_create.append(record._get_values())
+                values = record._get_values()
+                values.pop(parent_name, None)
+                to_create.append(values)
         if to_add:
             value.append(('add', to_add))
         if to_create:
@@ -514,8 +518,8 @@ class ModelList(list):
     def pop(self, index=-1):
         self.record_removed.add(self[index])
         self[index]._parent = None
-        self[index]._parent_field_name = None
-        self[index]._parent_name = None
+        self[index]._parent_field_name = ''
+        self[index]._parent_name = ''
         res = super(ModelList, self).pop(index)
         self._changed()
         return res
@@ -524,8 +528,8 @@ class ModelList(list):
     def remove(self, record):
         self.record_deleted.add(record)
         record._parent = None
-        record._parent_field_name = None
-        record._parent_name = None
+        record._parent_field_name = ''
+        record._parent_name = ''
         res = super(ModelList, self).remove(record)
         self._changed()
         return res
@@ -810,7 +814,7 @@ class Model(object):
             for record in to_remove:
                 # remove without signal
                 list.remove(getattr(self, field), record)
-            if value and value.get('add') or value.get('update'):
+            if value and (value.get('add') or value.get('update')):
                 for index, vals in value.get('add', []):
                     relation = Model.get(self._fields[field]['relation'],
                             self._config)
